/* A Bison parser, made by GNU Bison 1.875b.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Written by Richard Stallman by simplifying the original so called
   ``semantic'' parser.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output.  */
#define YYBISON 1

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 0

/* Using locations.  */
#define YYLSP_NEEDED 0

/* If NAME_PREFIX is specified substitute the variables and functions
   names.  */
#define yyparse lisp_parse
#define yylex   lisp_lex
#define yyerror lisp_error
#define yylval  lisp_lval
#define yychar  lisp_char
#define yydebug lisp_debug
#define yynerrs lisp_nerrs


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     IF = 258,
     ELSE = 259,
     CLASS = 260,
     RETURN = 261,
     WHILE = 262,
     DYNAMIC = 263,
     STATIC = 264,
     V_TRUE = 265,
     V_FALSE = 266,
     V_NULL = 267,
     GLOBAL = 268,
     FNCT = 269,
     LOCAL = 270,
     VOID = 271,
     CHAR = 272,
     UCHAR = 273,
     SHORT = 274,
     USHORT = 275,
     INT = 276,
     UINT = 277,
     FLOAT = 278,
     DOUBLE = 279,
     STRING = 280,
     BOOL = 281,
     IDENTIFIER = 282,
     V_INT = 283,
     V_FLOAT = 284,
     V_STRING = 285
   };
#endif
#define IF 258
#define ELSE 259
#define CLASS 260
#define RETURN 261
#define WHILE 262
#define DYNAMIC 263
#define STATIC 264
#define V_TRUE 265
#define V_FALSE 266
#define V_NULL 267
#define GLOBAL 268
#define FNCT 269
#define LOCAL 270
#define VOID 271
#define CHAR 272
#define UCHAR 273
#define SHORT 274
#define USHORT 275
#define INT 276
#define UINT 277
#define FLOAT 278
#define DOUBLE 279
#define STRING 280
#define BOOL 281
#define IDENTIFIER 282
#define V_INT 283
#define V_FLOAT 284
#define V_STRING 285




/* Copy the first part of user declarations.  */
#line 22 "parser/lisplike/langlisp_yacc.y"


#include <xltype.h>
#include <xlexpr.h>
#include <parser/clike/xllangc.h>


#ifndef YYDEBUG
#define	YYDEBUG	 0	/* Default to no yydebug support */
#endif

extern void yyerror (char *error);
extern int yylex () ;

extern XLExpr* g_xl_langlisp_expr;
extern xstr    g_xl_langlisp_filename;

XLExpr*  lisp_call_stack[1000];
xuint    lisp_call_num = 0;

XLExpr*  lisp_block_stack[1000];
xuint    lisp_block_num = 0;

XLExpr*  lisp_fnct = NULL;
XLExpr*  lisp_block = NULL;
XLExpr*  lisp_call = NULL;
XLType*  lisp_type = NULL;
XLData*  lisp_data = NULL;
XString* lisp_text = NULL;

XLExpr*  lisp_class = NULL;

xuint lisp_line = 1;



/* Enabling traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif

/* Enabling verbose error messages.  */
#ifdef YYERROR_VERBOSE
# undef YYERROR_VERBOSE
# define YYERROR_VERBOSE 1
#else
# define YYERROR_VERBOSE 0
#endif

#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 58 "parser/lisplike/langlisp_yacc.y"
typedef union YYSTYPE {
  XLExpr*     expr;
  XLTypeType  xtype;
  xdouble     val_float;
  xint        val_int;
  xchar       val_string[100];
  xchar       identifier[100];
} YYSTYPE;
/* Line 191 of yacc.c.  */
#line 190 "langlisp_yacc.c"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif



/* Copy the second part of user declarations.  */


/* Line 214 of yacc.c.  */
#line 202 "langlisp_yacc.c"

#if ! defined (yyoverflow) || YYERROR_VERBOSE

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# if YYSTACK_USE_ALLOCA
#  define YYSTACK_ALLOC alloca
# else
#  ifndef YYSTACK_USE_ALLOCA
#   if defined (alloca) || defined (_ALLOCA_H)
#    define YYSTACK_ALLOC alloca
#   else
#    ifdef __GNUC__
#     define YYSTACK_ALLOC __builtin_alloca
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's `empty if-body' warning. */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
# else
#  if defined (__STDC__) || defined (__cplusplus)
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   define YYSIZE_T size_t
#  endif
#  define YYSTACK_ALLOC malloc
#  define YYSTACK_FREE free
# endif
#endif /* ! defined (yyoverflow) || YYERROR_VERBOSE */


#if (! defined (yyoverflow) \
     && (! defined (__cplusplus) \
	 || (YYSTYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  short yyss;
  YYSTYPE yyvs;
  };

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (sizeof (short) + sizeof (YYSTYPE))				\
      + YYSTACK_GAP_MAXIMUM)

/* Copy COUNT objects from FROM to TO.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if 1 < __GNUC__
#   define YYCOPY(To, From, Count) \
      __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
#  else
#   define YYCOPY(To, From, Count)		\
      do					\
	{					\
	  register YYSIZE_T yyi;		\
	  for (yyi = 0; yyi < (Count); yyi++)	\
	    (To)[yyi] = (From)[yyi];		\
	}					\
      while (0)
#  endif
# endif

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack)					\
    do									\
      {									\
	YYSIZE_T yynewbytes;						\
	YYCOPY (&yyptr->Stack, Stack, yysize);				\
	Stack = &yyptr->Stack;						\
	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
	yyptr += yynewbytes / sizeof (*yyptr);				\
      }									\
    while (0)

#endif

#if defined (__STDC__) || defined (__cplusplus)
   typedef signed char yysigned_char;
#else
   typedef short yysigned_char;
#endif

/* YYFINAL -- State number of the termination state. */
#define YYFINAL  2
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   173

/* YYNTOKENS -- Number of terminals. */
#define YYNTOKENS  45
/* YYNNTS -- Number of nonterminals. */
#define YYNNTS  28
/* YYNRULES -- Number of rules. */
#define YYNRULES  73
/* YYNRULES -- Number of states. */
#define YYNSTATES  148

/* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
#define YYUNDEFTOK  2
#define YYMAXUTOK   285

#define YYTRANSLATE(YYX) 						\
  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)

/* YYTRANSLATE[YYLEX] -- Bison symbol number corresponding to YYLEX.  */
static const unsigned char yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,    43,     2,     2,     2,     2,     2,     2,
      32,    33,    39,    38,     2,    40,     2,    41,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,    31,
      36,    42,    37,     2,    44,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,    34,     2,    35,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30
};

#if YYDEBUG
/* YYPRHS[YYN] -- Index of the first RHS symbol of rule number YYN in
   YYRHS.  */
static const unsigned char yyprhs[] =
{
       0,     0,     3,     4,     7,     9,    11,    13,    15,    16,
      17,    24,    30,    38,    47,    50,    55,    61,    62,    64,
      67,    68,    77,    79,    81,    83,    85,    87,    89,    91,
      93,    95,    97,    99,   104,   109,   111,   113,   115,   117,
     119,   121,   123,   125,   127,   133,   139,   145,   151,   157,
     163,   170,   177,   184,   191,   198,   199,   201,   204,   205,
     208,   210,   212,   214,   215,   221,   223,   224,   227,   228,
     234,   240,   241,   243
};

/* YYRHS -- A `-1'-separated list of the rules' RHS. */
static const yysigned_char yyrhs[] =
{
      46,     0,    -1,    -1,    46,    47,    -1,    48,    -1,    51,
      -1,    54,    -1,     1,    -1,    -1,    -1,    32,     5,    58,
      49,    50,    33,    -1,    32,    13,    57,    58,    33,    -1,
      32,    13,    57,    34,    35,    58,    33,    -1,    32,    13,
      57,    34,    28,    35,    58,    33,    -1,    57,    58,    -1,
      57,    34,    35,    58,    -1,    57,    34,    28,    35,    58,
      -1,    -1,    52,    -1,    53,    52,    -1,    -1,    32,    14,
      57,    58,    55,    53,    64,    33,    -1,    16,    -1,    17,
      -1,    18,    -1,    19,    -1,    20,    -1,    21,    -1,    22,
      -1,    25,    -1,    23,    -1,    24,    -1,    56,    -1,     8,
      36,    58,    37,    -1,     9,    36,    58,    37,    -1,    27,
      -1,    30,    -1,    28,    -1,    29,    -1,    10,    -1,    11,
      -1,    59,    -1,    68,    -1,    58,    -1,    32,    38,    60,
      60,    33,    -1,    32,    39,    60,    60,    33,    -1,    32,
      40,    60,    60,    33,    -1,    32,    41,    60,    60,    33,
      -1,    32,    36,    60,    60,    33,    -1,    32,    37,    60,
      60,    33,    -1,    32,    34,    35,    60,    60,    33,    -1,
      32,    42,    42,    60,    60,    33,    -1,    32,    36,    42,
      60,    60,    33,    -1,    32,    37,    42,    60,    60,    33,
      -1,    32,    43,    42,    60,    60,    33,    -1,    -1,    60,
      -1,    61,    60,    -1,    -1,    62,    63,    -1,    68,    -1,
      70,    -1,    72,    -1,    -1,    32,    44,    65,    62,    33,
      -1,    64,    -1,    -1,    67,    63,    -1,    -1,    32,    58,
      69,    61,    33,    -1,    32,    42,    60,    60,    33,    -1,
      -1,    66,    -1,    32,     3,    60,    66,    71,    33,    -1
};

/* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
static const unsigned short yyrline[] =
{
       0,    88,    88,    90,    94,    95,    96,    97,   130,   132,
     129,   137,   139,   145,   171,   173,   179,   187,   189,   190,
     195,   194,   207,   208,   209,   210,   211,   212,   213,   214,
     215,   216,   220,   221,   222,   226,   231,   232,   233,   234,
     235,   243,   244,   245,   246,   247,   248,   249,   250,   251,
     252,   253,   254,   255,   256,   263,   265,   266,   274,   276,
     284,   285,   286,   295,   294,   302,   303,   303,   308,   307,
     315,   349,   350,   354
};
#endif

#if YYDEBUG || YYERROR_VERBOSE
/* YYTNME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals. */
static const char *const yytname[] =
{
  "$end", "error", "$undefined", "IF", "ELSE", "CLASS", "RETURN", "WHILE", 
  "DYNAMIC", "STATIC", "V_TRUE", "V_FALSE", "V_NULL", "GLOBAL", "FNCT", 
  "LOCAL", "VOID", "CHAR", "UCHAR", "SHORT", "USHORT", "INT", "UINT", 
  "FLOAT", "DOUBLE", "STRING", "BOOL", "IDENTIFIER", "V_INT", "V_FLOAT", 
  "V_STRING", "';'", "'('", "')'", "'['", "']'", "'<'", "'>'", "'+'", 
  "'*'", "'-'", "'/'", "'='", "'!'", "'@'", "$accept", "input", "decl", 
  "decl_class", "@2", "@3", "decl_global", "decl_param", 
  "decl_param_list", "decl_function", "@4", "type_basic", "type", 
  "identifier", "literal", "expr", "param_list", "code_lines", 
  "code_line", "code_block", "@5", "code_block_or_line", "@6", 
  "code_call", "@7", "code_assign", "code_if_else", "code_if", 0
};
#endif

# ifdef YYPRINT
/* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
   token YYLEX-NUM.  */
static const unsigned short yytoknum[] =
{
       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
     265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
     275,   276,   277,   278,   279,   280,   281,   282,   283,   284,
     285,    59,    40,    41,    91,    93,    60,    62,    43,    42,
      45,    47,    61,    33,    64
};
# endif

/* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
static const unsigned char yyr1[] =
{
       0,    45,    46,    46,    47,    47,    47,    47,    49,    50,
      48,    51,    51,    51,    52,    52,    52,    53,    53,    53,
      55,    54,    56,    56,    56,    56,    56,    56,    56,    56,
      56,    56,    57,    57,    57,    58,    59,    59,    59,    59,
      59,    60,    60,    60,    60,    60,    60,    60,    60,    60,
      60,    60,    60,    60,    60,    61,    61,    61,    62,    62,
      63,    63,    63,    65,    64,    66,    67,    66,    69,    68,
      70,    71,    71,    72
};

/* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
static const unsigned char yyr2[] =
{
       0,     2,     0,     2,     1,     1,     1,     1,     0,     0,
       6,     5,     7,     8,     2,     4,     5,     0,     1,     2,
       0,     8,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     4,     4,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     5,     5,     5,     5,     5,     5,
       6,     6,     6,     6,     6,     0,     1,     2,     0,     2,
       1,     1,     1,     0,     5,     1,     0,     2,     0,     5,
       5,     0,     1,     6
};

/* YYDEFACT[STATE-NAME] -- Default rule to reduce with in state
   STATE-NUM when YYTABLE doesn't specify something else to do.  Zero
   means the default is an error.  */
static const unsigned char yydefact[] =
{
       2,     0,     1,     7,     0,     3,     4,     5,     6,     0,
       0,     0,    35,     8,     0,     0,    22,    23,    24,    25,
      26,    27,    28,    30,    31,    29,    32,     0,     0,     9,
       0,     0,     0,     0,    20,     0,     0,     0,     0,     0,
      11,    17,    10,    33,    34,     0,     0,    18,     0,     0,
       0,    12,     0,    19,     0,     0,    14,    13,    63,    21,
       0,     0,    58,     0,    15,     0,    16,     0,    64,    59,
      60,    61,    62,     0,     0,    68,    39,    40,    37,    38,
      36,     0,    43,    41,     0,    42,     0,    55,     0,     0,
       0,     0,     0,     0,     0,     0,     0,    65,    71,     0,
       0,    56,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,    72,     0,    67,    70,    69,    57,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,    73,     0,     0,    48,     0,    49,    44,    45,    46,
      47,     0,     0,    50,    52,    53,    51,    54
};

/* YYDEFGOTO[NTERM-NUM]. */
static const yysigned_char yydefgoto[] =
{
      -1,     1,     5,     6,    29,    35,     7,    47,    48,     8,
      41,    26,    49,    82,    83,    84,   102,    65,    69,    97,
      62,    98,    99,    85,    87,    71,   115,    72
};

/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
   STATE-NUM.  */
#define YYPACT_NINF -65
static const short yypact[] =
{
     -65,     5,   -65,   -65,    -2,   -65,   -65,   -65,   -65,   -23,
     131,   131,   -65,   -65,   -28,   -21,   -65,   -65,   -65,   -65,
     -65,   -65,   -65,   -65,   -65,   -65,   -65,   -20,   -23,   -65,
     -23,   -23,   -19,   -10,   -65,    -4,    -5,    -3,     3,   -23,
     -65,   131,   -65,   -65,   -65,   -23,     0,   -65,    98,   -17,
       6,   -65,     1,   -65,     9,   -15,   -65,   -65,   -65,   -65,
      18,   -23,   -65,   -23,   -65,    -8,   -65,    -1,   -65,   -65,
     -65,   -65,   -65,   114,   114,   -65,   -65,   -65,   -65,   -65,
     -65,   130,   -65,   -65,    23,   -65,   114,   114,    21,    63,
      71,   114,   114,   114,   114,    15,    29,   -65,    23,    43,
      46,   -65,    99,   114,   114,   114,   114,   114,   114,   114,
     114,   114,   114,   114,   -65,    50,   -65,   -65,   -65,   -65,
     114,   114,    51,   114,    52,    55,    56,    61,    64,   114,
     114,   -65,    69,    75,   -65,    78,   -65,   -65,   -65,   -65,
     -65,    79,   100,   -65,   -65,   -65,   -65,   -65
};

/* YYPGOTO[NTERM-NUM].  */
static const yysigned_char yypgoto[] =
{
     -65,   -65,   -65,   -65,   -65,   -65,   -65,    28,   -65,   -65,
     -65,   -65,    17,    -9,   -65,   -43,   -65,   -65,    35,    48,
     -65,    37,   -65,   -64,   -65,   -65,   -65,   -65
};

/* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
   positive, shift that token.  If negative, reduce the rule which
   number is the opposite.  If zero, do what YYDEFACT says.
   If YYTABLE_NINF, syntax error.  */
#define YYTABLE_NINF -1
static const unsigned char yytable[] =
{
      13,    70,    73,     9,    12,     2,     3,    12,    30,    38,
      12,    10,    11,    60,    32,    31,    39,    55,    33,    34,
      61,    36,    37,    40,    67,    68,    12,    27,    28,    42,
      46,    86,    43,    51,    44,    70,    50,     4,    45,    57,
      56,    74,    59,   100,   101,    58,   105,   107,   108,   109,
     110,   111,    64,    63,    66,    52,   103,   112,    75,   119,
     120,   121,   122,   123,   124,   125,   126,   127,   128,   129,
     130,   113,    75,    76,    77,    67,    53,   132,   133,   117,
     135,    76,    77,   131,   134,   136,   141,   142,   137,   138,
      12,    78,    79,    80,   139,    81,    54,   140,    12,    78,
      79,    80,   143,    81,     0,   104,    14,    15,   144,    76,
      77,   145,   146,   106,    16,    17,    18,    19,    20,    21,
      22,    23,    24,    25,    76,    77,    12,    78,    79,    80,
      52,    81,   118,   147,   116,   114,     0,     0,     0,    14,
      15,    12,    78,    79,    80,     0,    81,    16,    17,    18,
      19,    20,    21,    22,    23,    24,    25,    12,     0,     0,
       0,     0,     0,     0,    88,     0,    89,    90,    91,    92,
      93,    94,    95,    96
};

static const short yycheck[] =
{
       9,    65,     3,     5,    27,     0,     1,    27,    36,    28,
      27,    13,    14,    28,    34,    36,    35,    34,    27,    28,
      35,    30,    31,    33,    32,    33,    27,    10,    11,    33,
      39,    74,    37,    33,    37,    99,    45,    32,    35,    33,
      49,    42,    33,    86,    87,    44,    89,    90,    91,    92,
      93,    94,    61,    35,    63,    32,    35,    42,    67,   102,
     103,   104,   105,   106,   107,   108,   109,   110,   111,   112,
     113,    42,    81,    10,    11,    32,    48,   120,   121,    33,
     123,    10,    11,    33,    33,    33,   129,   130,    33,    33,
      27,    28,    29,    30,    33,    32,    48,    33,    27,    28,
      29,    30,    33,    32,    -1,    42,     8,     9,    33,    10,
      11,    33,    33,    42,    16,    17,    18,    19,    20,    21,
      22,    23,    24,    25,    10,    11,    27,    28,    29,    30,
      32,    32,    33,    33,    99,    98,    -1,    -1,    -1,     8,
       9,    27,    28,    29,    30,    -1,    32,    16,    17,    18,
      19,    20,    21,    22,    23,    24,    25,    27,    -1,    -1,
      -1,    -1,    -1,    -1,    34,    -1,    36,    37,    38,    39,
      40,    41,    42,    43
};

/* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
   symbol of state STATE-NUM.  */
static const unsigned char yystos[] =
{
       0,    46,     0,     1,    32,    47,    48,    51,    54,     5,
      13,    14,    27,    58,     8,     9,    16,    17,    18,    19,
      20,    21,    22,    23,    24,    25,    56,    57,    57,    49,
      36,    36,    34,    58,    58,    50,    58,    58,    28,    35,
      33,    55,    33,    37,    37,    35,    58,    52,    53,    57,
      58,    33,    32,    52,    64,    34,    58,    33,    44,    33,
      28,    35,    65,    35,    58,    62,    58,    32,    33,    63,
      68,    70,    72,     3,    42,    58,    10,    11,    28,    29,
      30,    32,    58,    59,    60,    68,    60,    69,    34,    36,
      37,    38,    39,    40,    41,    42,    43,    64,    66,    67,
      60,    60,    61,    35,    42,    60,    42,    60,    60,    60,
      60,    60,    42,    42,    66,    71,    63,    33,    33,    60,
      60,    60,    60,    60,    60,    60,    60,    60,    60,    60,
      60,    33,    60,    60,    33,    60,    33,    33,    33,    33,
      33,    60,    60,    33,    33,    33,    33,    33
};

#if ! defined (YYSIZE_T) && defined (__SIZE_TYPE__)
# define YYSIZE_T __SIZE_TYPE__
#endif
#if ! defined (YYSIZE_T) && defined (size_t)
# define YYSIZE_T size_t
#endif
#if ! defined (YYSIZE_T)
# if defined (__STDC__) || defined (__cplusplus)
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# endif
#endif
#if ! defined (YYSIZE_T)
# define YYSIZE_T unsigned int
#endif

#define yyerrok		(yyerrstatus = 0)
#define yyclearin	(yychar = YYEMPTY)
#define YYEMPTY		(-2)
#define YYEOF		0

#define YYACCEPT	goto yyacceptlab
#define YYABORT		goto yyabortlab
#define YYERROR		goto yyerrlab1


/* Like YYERROR except do call yyerror.  This remains here temporarily
   to ease the transition to the new meaning of YYERROR, for GCC.
   Once GCC version 2 has supplanted version 1, this can go.  */

#define YYFAIL		goto yyerrlab

#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)					\
do								\
  if (yychar == YYEMPTY && yylen == 1)				\
    {								\
      yychar = (Token);						\
      yylval = (Value);						\
      yytoken = YYTRANSLATE (yychar);				\
      YYPOPSTACK;						\
      goto yybackup;						\
    }								\
  else								\
    { 								\
      yyerror ("syntax error: cannot back up");\
      YYERROR;							\
    }								\
while (0)

#define YYTERROR	1
#define YYERRCODE	256

/* YYLLOC_DEFAULT -- Compute the default location (before the actions
   are run).  */

#ifndef YYLLOC_DEFAULT
# define YYLLOC_DEFAULT(Current, Rhs, N)         \
  Current.first_line   = Rhs[1].first_line;      \
  Current.first_column = Rhs[1].first_column;    \
  Current.last_line    = Rhs[N].last_line;       \
  Current.last_column  = Rhs[N].last_column;
#endif

/* YYLEX -- calling `yylex' with the right arguments.  */

#ifdef YYLEX_PARAM
# define YYLEX yylex (YYLEX_PARAM)
#else
# define YYLEX yylex ()
#endif

/* Enable debugging if requested.  */
#if YYDEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)			\
do {						\
  if (yydebug)					\
    YYFPRINTF Args;				\
} while (0)

# define YYDSYMPRINT(Args)			\
do {						\
  if (yydebug)					\
    yysymprint Args;				\
} while (0)

# define YYDSYMPRINTF(Title, Token, Value, Location)		\
do {								\
  if (yydebug)							\
    {								\
      YYFPRINTF (stderr, "%s ", Title);				\
      yysymprint (stderr, 					\
                  Token, Value);	\
      YYFPRINTF (stderr, "\n");					\
    }								\
} while (0)

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (cinluded).                                                   |
`------------------------------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yy_stack_print (short *bottom, short *top)
#else
static void
yy_stack_print (bottom, top)
    short *bottom;
    short *top;
#endif
{
  YYFPRINTF (stderr, "Stack now");
  for (/* Nothing. */; bottom <= top; ++bottom)
    YYFPRINTF (stderr, " %d", *bottom);
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)				\
do {								\
  if (yydebug)							\
    yy_stack_print ((Bottom), (Top));				\
} while (0)


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yy_reduce_print (int yyrule)
#else
static void
yy_reduce_print (yyrule)
    int yyrule;
#endif
{
  int yyi;
  unsigned int yylno = yyrline[yyrule];
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %u), ",
             yyrule - 1, yylno);
  /* Print the symbols being reduced, and their result.  */
  for (yyi = yyprhs[yyrule]; 0 <= yyrhs[yyi]; yyi++)
    YYFPRINTF (stderr, "%s ", yytname [yyrhs[yyi]]);
  YYFPRINTF (stderr, "-> %s\n", yytname [yyr1[yyrule]]);
}

# define YY_REDUCE_PRINT(Rule)		\
do {					\
  if (yydebug)				\
    yy_reduce_print (Rule);		\
} while (0)

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !YYDEBUG */
# define YYDPRINTF(Args)
# define YYDSYMPRINT(Args)
# define YYDSYMPRINTF(Title, Token, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !YYDEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef	YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#if YYMAXDEPTH == 0
# undef YYMAXDEPTH
#endif

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif



#if YYERROR_VERBOSE

# ifndef yystrlen
#  if defined (__GLIBC__) && defined (_STRING_H)
#   define yystrlen strlen
#  else
/* Return the length of YYSTR.  */
static YYSIZE_T
#   if defined (__STDC__) || defined (__cplusplus)
yystrlen (const char *yystr)
#   else
yystrlen (yystr)
     const char *yystr;
#   endif
{
  register const char *yys = yystr;

  while (*yys++ != '\0')
    continue;

  return yys - yystr - 1;
}
#  endif
# endif

# ifndef yystpcpy
#  if defined (__GLIBC__) && defined (_STRING_H) && defined (_GNU_SOURCE)
#   define yystpcpy stpcpy
#  else
/* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
   YYDEST.  */
static char *
#   if defined (__STDC__) || defined (__cplusplus)
yystpcpy (char *yydest, const char *yysrc)
#   else
yystpcpy (yydest, yysrc)
     char *yydest;
     const char *yysrc;
#   endif
{
  register char *yyd = yydest;
  register const char *yys = yysrc;

  while ((*yyd++ = *yys++) != '\0')
    continue;

  return yyd - 1;
}
#  endif
# endif

#endif /* !YYERROR_VERBOSE */



#if YYDEBUG
/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yysymprint (FILE *yyoutput, int yytype, YYSTYPE *yyvaluep)
#else
static void
yysymprint (yyoutput, yytype, yyvaluep)
    FILE *yyoutput;
    int yytype;
    YYSTYPE *yyvaluep;
#endif
{
  /* Pacify ``unused variable'' warnings.  */
  (void) yyvaluep;

  if (yytype < YYNTOKENS)
    {
      YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
# ifdef YYPRINT
      YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
# endif
    }
  else
    YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);

  switch (yytype)
    {
      default:
        break;
    }
  YYFPRINTF (yyoutput, ")");
}

#endif /* ! YYDEBUG */
/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yydestruct (int yytype, YYSTYPE *yyvaluep)
#else
static void
yydestruct (yytype, yyvaluep)
    int yytype;
    YYSTYPE *yyvaluep;
#endif
{
  /* Pacify ``unused variable'' warnings.  */
  (void) yyvaluep;

  switch (yytype)
    {

      default:
        break;
    }
}


/* Prevent warnings from -Wmissing-prototypes.  */

#ifdef YYPARSE_PARAM
# if defined (__STDC__) || defined (__cplusplus)
int yyparse (void *YYPARSE_PARAM);
# else
int yyparse ();
# endif
#else /* ! YYPARSE_PARAM */
#if defined (__STDC__) || defined (__cplusplus)
int yyparse (void);
#else
int yyparse ();
#endif
#endif /* ! YYPARSE_PARAM */



/* The lookahead symbol.  */
int yychar;

/* The semantic value of the lookahead symbol.  */
YYSTYPE yylval;

/* Number of syntax errors so far.  */
int yynerrs;



/*----------.
| yyparse.  |
`----------*/

#ifdef YYPARSE_PARAM
# if defined (__STDC__) || defined (__cplusplus)
int yyparse (void *YYPARSE_PARAM)
# else
int yyparse (YYPARSE_PARAM)
  void *YYPARSE_PARAM;
# endif
#else /* ! YYPARSE_PARAM */
#if defined (__STDC__) || defined (__cplusplus)
int
yyparse (void)
#else
int
yyparse ()

#endif
#endif
{
  
  register int yystate;
  register int yyn;
  int yyresult;
  /* Number of tokens to shift before error messages enabled.  */
  int yyerrstatus;
  /* Lookahead token as an internal (translated) token number.  */
  int yytoken = 0;

  /* Three stacks and their tools:
     `yyss': related to states,
     `yyvs': related to semantic values,
     `yyls': related to locations.

     Refer to the stacks thru separate pointers, to allow yyoverflow
     to reallocate them elsewhere.  */

  /* The state stack.  */
  short	yyssa[YYINITDEPTH];
  short *yyss = yyssa;
  register short *yyssp;

  /* The semantic value stack.  */
  YYSTYPE yyvsa[YYINITDEPTH];
  YYSTYPE *yyvs = yyvsa;
  register YYSTYPE *yyvsp;



#define YYPOPSTACK   (yyvsp--, yyssp--)

  YYSIZE_T yystacksize = YYINITDEPTH;

  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;


  /* When reducing, the number of symbols on the RHS of the reduced
     rule.  */
  int yylen;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yystate = 0;
  yyerrstatus = 0;
  yynerrs = 0;
  yychar = YYEMPTY;		/* Cause a token to be read.  */

  /* Initialize stack pointers.
     Waste one element of value and location stack
     so that they stay on the same level as the state stack.
     The wasted elements are never initialized.  */

  yyssp = yyss;
  yyvsp = yyvs;

  goto yysetstate;

/*------------------------------------------------------------.
| yynewstate -- Push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
 yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed. so pushing a state here evens the stacks.
     */
  yyssp++;

 yysetstate:
  *yyssp = yystate;

  if (yyss + yystacksize - 1 <= yyssp)
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYSIZE_T yysize = yyssp - yyss + 1;

#ifdef yyoverflow
      {
	/* Give user a chance to reallocate the stack. Use copies of
	   these so that the &'s don't force the real ones into
	   memory.  */
	YYSTYPE *yyvs1 = yyvs;
	short *yyss1 = yyss;


	/* Each stack pointer address is followed by the size of the
	   data in use in that stack, in bytes.  This used to be a
	   conditional around just the two extra args, but that might
	   be undefined if yyoverflow is a macro.  */
	yyoverflow ("parser stack overflow",
		    &yyss1, yysize * sizeof (*yyssp),
		    &yyvs1, yysize * sizeof (*yyvsp),

		    &yystacksize);

	yyss = yyss1;
	yyvs = yyvs1;
      }
#else /* no yyoverflow */
# ifndef YYSTACK_RELOCATE
      goto yyoverflowlab;
# else
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
	goto yyoverflowlab;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
	yystacksize = YYMAXDEPTH;

      {
	short *yyss1 = yyss;
	union yyalloc *yyptr =
	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
	if (! yyptr)
	  goto yyoverflowlab;
	YYSTACK_RELOCATE (yyss);
	YYSTACK_RELOCATE (yyvs);

#  undef YYSTACK_RELOCATE
	if (yyss1 != yyssa)
	  YYSTACK_FREE (yyss1);
      }
# endif
#endif /* no yyoverflow */

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;


      YYDPRINTF ((stderr, "Stack size increased to %lu\n",
		  (unsigned long int) yystacksize));

      if (yyss + yystacksize - 1 <= yyssp)
	YYABORT;
    }

  YYDPRINTF ((stderr, "Entering state %d\n", yystate));

  goto yybackup;

/*-----------.
| yybackup.  |
`-----------*/
yybackup:

/* Do appropriate processing given the current state.  */
/* Read a lookahead token if we need one and don't already have one.  */
/* yyresume: */

  /* First try to decide what to do without reference to lookahead token.  */

  yyn = yypact[yystate];
  if (yyn == YYPACT_NINF)
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
  if (yychar == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token: "));
      yychar = YYLEX;
    }

  if (yychar <= YYEOF)
    {
      yychar = yytoken = YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YYDSYMPRINTF ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yyn == 0 || yyn == YYTABLE_NINF)
	goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  if (yyn == YYFINAL)
    YYACCEPT;

  /* Shift the lookahead token.  */
  YYDPRINTF ((stderr, "Shifting token %s, ", yytname[yytoken]));

  /* Discard the token being shifted unless it is eof.  */
  if (yychar != YYEOF)
    yychar = YYEMPTY;

  *++yyvsp = yylval;


  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  yystate = yyn;
  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- Do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     `$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];


  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
        case 4:
#line 94 "parser/lisplike/langlisp_yacc.y"
    { xl_lang_decl_add (yyvsp[0].expr); }
    break;

  case 5:
#line 95 "parser/lisplike/langlisp_yacc.y"
    { xl_lang_decl_add (yyvsp[0].expr); }
    break;

  case 6:
#line 96 "parser/lisplike/langlisp_yacc.y"
    { xl_lang_decl_add (yyvsp[0].expr); }
    break;

  case 7:
#line 97 "parser/lisplike/langlisp_yacc.y"
    { xl_lang_lisp_error ("Expecting a declaration"); }
    break;

  case 8:
#line 130 "parser/lisplike/langlisp_yacc.y"
    { xl_lang_class_create (yyvsp[0].expr, NULL); }
    break;

  case 9:
#line 132 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_lang_class_finish (); }
    break;

  case 11:
#line 138 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 ("global", yyvsp[-2].expr, yyvsp[-1].expr); }
    break;

  case 12:
#line 140 "parser/lisplike/langlisp_yacc.y"
    {
      yyvsp[-4].expr->type->array_type = XL_TYPE_ARRAY_TYPE_DYNAMIC;
      yyvsp[-4].expr->type->array_size = 0;
      yyval.expr = xl_lang_efnct_create2 ("global", yyvsp[-4].expr, yyvsp[-1].expr);
    }
    break;

  case 13:
#line 146 "parser/lisplike/langlisp_yacc.y"
    {
      yyvsp[-5].expr->type->array_type = XL_TYPE_ARRAY_TYPE_FIXED;
      yyvsp[-5].expr->type->array_size = yyvsp[-3].val_int;
      yyval.expr = xl_lang_efnct_create2 ("global", yyvsp[-5].expr, yyvsp[-1].expr);
    }
    break;

  case 14:
#line 172 "parser/lisplike/langlisp_yacc.y"
    { xl_lang_fnct_add_param (yyvsp[-1].expr, yyvsp[0].expr); }
    break;

  case 15:
#line 174 "parser/lisplike/langlisp_yacc.y"
    {
      yyvsp[-3].expr->type->array_type = XL_TYPE_ARRAY_TYPE_DYNAMIC;
      yyvsp[-3].expr->type->array_size = 0;
      xl_lang_fnct_add_param (yyvsp[-3].expr, yyvsp[0].expr);
    }
    break;

  case 16:
#line 180 "parser/lisplike/langlisp_yacc.y"
    {
      yyvsp[-4].expr->type->array_type = XL_TYPE_ARRAY_TYPE_FIXED;
      yyvsp[-4].expr->type->array_size = yyvsp[-2].val_int;
      xl_lang_fnct_add_param (yyvsp[-4].expr, yyvsp[0].expr);
    }
    break;

  case 20:
#line 195 "parser/lisplike/langlisp_yacc.y"
    { xl_lang_fnct_create (yyvsp[-1].expr, yyvsp[0].expr);  }
    break;

  case 21:
#line 199 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_lang_fnct_finish (yyvsp[-1].expr); }
    break;

  case 22:
#line 207 "parser/lisplike/langlisp_yacc.y"
    { yyval.xtype = XL_TYPE_TYPE_VOID;    }
    break;

  case 23:
#line 208 "parser/lisplike/langlisp_yacc.y"
    { yyval.xtype = XL_TYPE_TYPE_CHAR;    }
    break;

  case 24:
#line 209 "parser/lisplike/langlisp_yacc.y"
    { yyval.xtype = XL_TYPE_TYPE_UCHAR;   }
    break;

  case 25:
#line 210 "parser/lisplike/langlisp_yacc.y"
    { yyval.xtype = XL_TYPE_TYPE_SHORT;   }
    break;

  case 26:
#line 211 "parser/lisplike/langlisp_yacc.y"
    { yyval.xtype = XL_TYPE_TYPE_USHORT;  }
    break;

  case 27:
#line 212 "parser/lisplike/langlisp_yacc.y"
    { yyval.xtype = XL_TYPE_TYPE_INT;     }
    break;

  case 28:
#line 213 "parser/lisplike/langlisp_yacc.y"
    { yyval.xtype = XL_TYPE_TYPE_UINT;    }
    break;

  case 29:
#line 214 "parser/lisplike/langlisp_yacc.y"
    { yyval.xtype = XL_TYPE_TYPE_STRING;  }
    break;

  case 30:
#line 215 "parser/lisplike/langlisp_yacc.y"
    { yyval.xtype = XL_TYPE_TYPE_FLOAT;   }
    break;

  case 31:
#line 216 "parser/lisplike/langlisp_yacc.y"
    { yyval.xtype = XL_TYPE_TYPE_DOUBLE;  }
    break;

  case 32:
#line 220 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_lang_type_create (yyvsp[0].xtype, XL_TYPE_ARRAY_TYPE_NONE, 0, NULL); }
    break;

  case 33:
#line 221 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_expr_new (); }
    break;

  case 34:
#line 222 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_expr_new (); }
    break;

  case 35:
#line 227 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr =  xl_expr_new_identifier (yyvsp[0].identifier); }
    break;

  case 36:
#line 231 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_lang_data_string_create (yyvsp[0].val_string);   }
    break;

  case 37:
#line 232 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_lang_data_integer_create (yyvsp[0].val_int);  }
    break;

  case 38:
#line 233 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_lang_data_float_create (yyvsp[0].val_float);    }
    break;

  case 39:
#line 234 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_lang_data_bool_create (TRUE);   }
    break;

  case 40:
#line 235 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_lang_data_bool_create (FALSE);  }
    break;

  case 41:
#line 243 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = yyvsp[0].expr; }
    break;

  case 42:
#line 244 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = yyvsp[0].expr; }
    break;

  case 43:
#line 245 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = yyvsp[0].expr; }
    break;

  case 44:
#line 246 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 ("+", yyvsp[-2].expr, yyvsp[-1].expr); }
    break;

  case 45:
#line 247 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 ("*", yyvsp[-2].expr, yyvsp[-1].expr); }
    break;

  case 46:
#line 248 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 ("-", yyvsp[-2].expr, yyvsp[-1].expr); }
    break;

  case 47:
#line 249 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 ("/", yyvsp[-2].expr, yyvsp[-1].expr); }
    break;

  case 48:
#line 250 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 ("<", yyvsp[-2].expr, yyvsp[-1].expr); }
    break;

  case 49:
#line 251 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 (">", yyvsp[-2].expr, yyvsp[-1].expr); }
    break;

  case 50:
#line 252 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 ("[]", yyvsp[-2].expr, yyvsp[-1].expr); }
    break;

  case 51:
#line 253 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 ("==", yyvsp[-2].expr, yyvsp[-1].expr); }
    break;

  case 52:
#line 254 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 ("<=", yyvsp[-2].expr, yyvsp[-1].expr); }
    break;

  case 53:
#line 255 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 (">=", yyvsp[-2].expr, yyvsp[-1].expr); }
    break;

  case 54:
#line 256 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 ("<>", yyvsp[-2].expr, yyvsp[-1].expr); }
    break;

  case 56:
#line 265 "parser/lisplike/langlisp_yacc.y"
    { xl_lang_call_add (yyvsp[0].expr); }
    break;

  case 57:
#line 266 "parser/lisplike/langlisp_yacc.y"
    { xl_lang_call_add (yyvsp[0].expr); }
    break;

  case 60:
#line 284 "parser/lisplike/langlisp_yacc.y"
    { xl_lang_block_add (yyvsp[0].expr); }
    break;

  case 61:
#line 285 "parser/lisplike/langlisp_yacc.y"
    { xl_lang_block_add (yyvsp[0].expr); }
    break;

  case 62:
#line 286 "parser/lisplike/langlisp_yacc.y"
    { xl_lang_block_add (yyvsp[0].expr); }
    break;

  case 63:
#line 295 "parser/lisplike/langlisp_yacc.y"
    { xl_lang_block_begin (); }
    break;

  case 64:
#line 298 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_lang_block_end (); }
    break;

  case 65:
#line 302 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = yyvsp[0].expr; }
    break;

  case 66:
#line 303 "parser/lisplike/langlisp_yacc.y"
    { xl_lang_block_begin (); }
    break;

  case 67:
#line 303 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_lang_block_end (); }
    break;

  case 68:
#line 308 "parser/lisplike/langlisp_yacc.y"
    { xl_lang_call_begin (x_string_get_str (yyvsp[0].expr->identifier)); }
    break;

  case 69:
#line 311 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_lang_call_end (); }
    break;

  case 70:
#line 316 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = xl_lang_efnct_create2 ("=", yyvsp[-2].expr, yyvsp[-1].expr); }
    break;

  case 71:
#line 349 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = NULL; }
    break;

  case 72:
#line 350 "parser/lisplike/langlisp_yacc.y"
    { yyval.expr = yyvsp[0].expr; }
    break;

  case 73:
#line 358 "parser/lisplike/langlisp_yacc.y"
    {
      yyval.expr = xl_lang_efnct_create2 ("if", yyvsp[-3].expr, yyvsp[-2].expr); 
      if (yyvsp[-1].expr)
	{
	  xl_expr_add (yyval.expr, yyvsp[-1].expr);
	  x_unref (yyvsp[-1].expr);
	}
    }
    break;


    }

/* Line 999 of yacc.c.  */
#line 1549 "langlisp_yacc.c"

  yyvsp -= yylen;
  yyssp -= yylen;


  YY_STACK_PRINT (yyss, yyssp);

  *++yyvsp = yyval;


  /* Now `shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */

  yyn = yyr1[yyn];

  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
    yystate = yytable[yystate];
  else
    yystate = yydefgoto[yyn - YYNTOKENS];

  goto yynewstate;


/*------------------------------------.
| yyerrlab -- here on detecting error |
`------------------------------------*/
yyerrlab:
  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
#if YYERROR_VERBOSE
      yyn = yypact[yystate];

      if (YYPACT_NINF < yyn && yyn < YYLAST)
	{
	  YYSIZE_T yysize = 0;
	  int yytype = YYTRANSLATE (yychar);
	  const char* yyprefix;
	  char *yymsg;
	  int yyx;

	  /* Start YYX at -YYN if negative to avoid negative indexes in
	     YYCHECK.  */
	  int yyxbegin = yyn < 0 ? -yyn : 0;

	  /* Stay within bounds of both yycheck and yytname.  */
	  int yychecklim = YYLAST - yyn;
	  int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
	  int yycount = 0;

	  yyprefix = ", expecting ";
	  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
	    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
	      {
		yysize += yystrlen (yyprefix) + yystrlen (yytname [yyx]);
		yycount += 1;
		if (yycount == 5)
		  {
		    yysize = 0;
		    break;
		  }
	      }
	  yysize += (sizeof ("syntax error, unexpected ")
		     + yystrlen (yytname[yytype]));
	  yymsg = (char *) YYSTACK_ALLOC (yysize);
	  if (yymsg != 0)
	    {
	      char *yyp = yystpcpy (yymsg, "syntax error, unexpected ");
	      yyp = yystpcpy (yyp, yytname[yytype]);

	      if (yycount < 5)
		{
		  yyprefix = ", expecting ";
		  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
		    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
		      {
			yyp = yystpcpy (yyp, yyprefix);
			yyp = yystpcpy (yyp, yytname[yyx]);
			yyprefix = " or ";
		      }
		}
	      yyerror (yymsg);
	      YYSTACK_FREE (yymsg);
	    }
	  else
	    yyerror ("syntax error; also virtual memory exhausted");
	}
      else
#endif /* YYERROR_VERBOSE */
	yyerror ("syntax error");
    }



  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
	 error, discard it.  */

      /* Return failure if at end of input.  */
      if (yychar == YYEOF)
        {
	  /* Pop the error token.  */
          YYPOPSTACK;
	  /* Pop the rest of the stack.  */
	  while (yyss < yyssp)
	    {
	      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
	      yydestruct (yystos[*yyssp], yyvsp);
	      YYPOPSTACK;
	    }
	  YYABORT;
        }

      YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
      yydestruct (yytoken, &yylval);
      yychar = YYEMPTY;

    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */
  goto yyerrlab1;


/*----------------------------------------------------.
| yyerrlab1 -- error raised explicitly by an action.  |
`----------------------------------------------------*/
yyerrlab1:
  yyerrstatus = 3;	/* Each real token shifted decrements this.  */

  for (;;)
    {
      yyn = yypact[yystate];
      if (yyn != YYPACT_NINF)
	{
	  yyn += YYTERROR;
	  if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYTERROR)
	    {
	      yyn = yytable[yyn];
	      if (0 < yyn)
		break;
	    }
	}

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
	YYABORT;

      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
      yydestruct (yystos[yystate], yyvsp);
      yyvsp--;
      yystate = *--yyssp;

      YY_STACK_PRINT (yyss, yyssp);
    }

  if (yyn == YYFINAL)
    YYACCEPT;

  YYDPRINTF ((stderr, "Shifting error token, "));

  *++yyvsp = yylval;


  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturn;

/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturn;

#ifndef yyoverflow
/*----------------------------------------------.
| yyoverflowlab -- parser overflow comes here.  |
`----------------------------------------------*/
yyoverflowlab:
  yyerror ("parser stack overflow");
  yyresult = 2;
  /* Fall through.  */
#endif

yyreturn:
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif
  return yyresult;
}


#line 368 "parser/lisplike/langlisp_yacc.y"


